@@ -1,10 +1,11 @@
-use 5.008;    # utf8
+use 5.006;    # our
 use strict;
 use warnings;
-use utf8;
 
 package Git::Wrapper::Plus::Ref;
-$Git::Wrapper::Plus::Ref::VERSION = '0.004010';
+
+our $VERSION = '0.004011';
+
 # ABSTRACT: An Abstract REF node
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
@@ -97,7 +98,7 @@ Git::Wrapper::Plus::Ref - An Abstract REF node
 
 =head1 VERSION
 
-version 0.004010
+version 0.004011
 
 =head1 SYNOPSIS
 
@@ -149,11 +150,11 @@ B<REQUIRED>: A C<Git::Wrapper> compatible object for resolving C<sha1> internals
 
 =head1 AUTHOR
 
-Kent Fredric <kentfredric@gmail.com>
+Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2017 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
