@@ -1,10 +1,11 @@
-use 5.008;    # utf8
+use 5.006;    # our
 use strict;
 use warnings;
-use utf8;
 
 package Git::Wrapper::Plus::Support::Commands;
-$Git::Wrapper::Plus::Support::Commands::VERSION = '0.004010';
+
+our $VERSION = '0.004011';
+
 # ABSTRACT: Database of command support data
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
@@ -146,7 +147,7 @@ Git::Wrapper::Plus::Support::Commands - Database of command support data
 
 =head1 VERSION
 
-version 0.004010
+version 0.004011
 
 =head1 SUPPORTED COMMANDS
 
@@ -202,11 +203,11 @@ Was present in the first git commit, 0.99
 
 =head1 AUTHOR
 
-Kent Fredric <kentfredric@gmail.com>
+Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2017 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
