@@ -1,10 +1,11 @@
-use 5.008;    # utf8
+use 5.006;    # our
 use strict;
 use warnings;
-use utf8;
 
 package Git::Wrapper::Plus::Support::Range;
-$Git::Wrapper::Plus::Support::Range::VERSION = '0.004010';
+
+our $VERSION = '0.004011';
+
 # ABSTRACT: A record describing a range of supported versions
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
@@ -124,7 +125,7 @@ Git::Wrapper::Plus::Support::Range - A record describing a range of supported ve
 
 =head1 VERSION
 
-version 0.004010
+version 0.004011
 
 =head1 SYNOPSIS
 
@@ -180,15 +181,15 @@ The C<sha1> this feature was added in. Annotative only, not used.
 
 The C<sha1> this feature was removed in. Annotative only, not used.
 
-=for Pod::Coverage::TrustPod BUILD
+=for Pod::Coverage::TrustPod BUILD has_max has_max_sha1 has_max_tag has_min has_min_sha1 has_min_tag
 
 =head1 AUTHOR
 
-Kent Fredric <kentfredric@gmail.com>
+Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2017 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
