@@ -1,10 +1,11 @@
-use 5.008;    # utf8
+use 5.006;    # our
 use strict;
 use warnings;
-use utf8;
 
 package Git::Wrapper::Plus::Support::RangeSet;
-$Git::Wrapper::Plus::Support::RangeSet::VERSION = '0.004010';
+
+our $VERSION = '0.004011';
+
 # ABSTRACT: A set of ranges of supported things
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
@@ -96,7 +97,7 @@ Git::Wrapper::Plus::Support::RangeSet - A set of ranges of supported things
 
 =head1 VERSION
 
-version 0.004010
+version 0.004011
 
 =head1 METHODS
 
@@ -132,11 +133,11 @@ The series of L<< C<::Range>|Git::Wrapper::Plus::Support::Range >> objects that
 
 =head1 AUTHOR
 
-Kent Fredric <kentfredric@gmail.com>
+Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2017 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
